==> ocstore25_6_20.zip: OcStore/Spiky/GameScript.h <==
#pragma once
#include "global.h"
//ǰ
class Entity;
struct GameInput;
class GameMap;
class EntityRes;
class GameFade;
class MyCamera;
class GameMsgbox;
class MyGame;

struct EventInfo
{
	std::wstring eventName;
	std::wstring triggerType;
};
//Ϸű
class GameScript
{
public:
	void Init(MyGame* pGame);
	void EachNOD(bool bEachNOD, int targetNOD_playerIndex);//NODֻܱĿӦ
	//űǷ
	bool IsRunning();
	void StartEvent(const wchar_t* eventName,const wchar_t* triggerType);//¼
	void EndEvent();
	void TRA(const wchar_t* mapName, const wchar_t* eventName);
	//нű
	void Step();
	void SetWait(int wait);
	bool GetNOD();
	void SetNOD(bool nod);
	bool GetPRI();
	void SetPRI(bool pri);
	bool GetKEY();
	void SetKEY(bool key);
	void Reset();
	void SetWAS(bool was = true);
	void SetYNJ();
	bool GetYES();
	void SetW99(bool w99);
	bool GetW99();
	void SetNODBlock();
	const wchar_t* GetTriggerType();
	void SetCheckEntity(std::weak_ptr<Entity> e);
	std::weak_ptr<Entity> GetCheckEntity();
	void SetCheckItemIndex(int itemIndex);
	int GetCheckItemIndex();
private:
	std::list<std::shared_ptr<Entity>>* globalEntity = nullptr;
	GameMap* pGameMap = nullptr;
	EntityRes* pEntityRes = nullptr;
	GameFade* pGameFade = nullptr;
	MyCamera* pMyCamera = nullptr;
	GameMsgbox* pGameMsgbox = nullptr;
	MyGame* pGame = nullptr;
	lua_State** scriptL_ptr = nullptr;
	bool cmd_PRI = false;//ϷǷס
	bool cmd_KEY = false;//μ̲
	bool cmd_WAS = false;//ͣűֱڵ
	bool cmd_NOD = false;//ȴҰz
	bool cmd_YNJ = false;//ȴѡ
	int cmd_WAI = 0;//űʱȴ
	bool cmd_W99 = false;//ȴƷ
	bool bTRA = false;
	bool bYes = false;//YNJһεѡ
	bool NOD_block = false;//ֹNOD
	bool bEachNOD = false;//1NOD2ֿ
	int targetNOD_playerIndex = 0;//NODָӦĿ
	std::weak_ptr<Entity> checkEntity;//һεʵ
	int checkItemIndex = -1;//ڵƷ±
	std::wstring mapTRA;//Ŀ괫͵ͼ
	std::wstring triggerType;//
	std::vector<char> gbk;
	std::vector<wchar_t> wbuff;
	std::vector<EventInfo> eventStack;
	void PreventJumpNOD();
	bool YesNoControl();
	bool NODStep();
};

==> ocstore25_7_23.zip: OcStore/Spiky/GameScript.h <==
#pragma once
#include "global.h"
//ǰ
class Entity;
struct GameInput;
class GameMap;
class EntityRes;
class GameFade;
class MyCamera;
class GameMsgbox;
class MyGame;

struct EventInfo
{
	std::wstring eventName;
	std::wstring triggerType;
};
//Ϸű
class GameScript
{
public:
	void Init(MyGame* pGame);
	void EachNOD(bool bEachNOD, int targetNOD_playerIndex);//NODֻܱĿӦ
	//űǷ
	bool IsRunning();
	void StartEvent(const wchar_t* eventName,const wchar_t* triggerType);//¼
	void EndEvent();
	void TRA(const wchar_t* mapName, const wchar_t* eventName);
	//нű
	void Step();
	void SetWait(int wait);
	bool GetNOD();
	void SetNOD(bool nod);
	bool GetPRI();
	void SetPRI(bool pri);
	bool GetKEY();
	void SetKEY(bool key);
	void Reset();
	void SetWAS(bool was = true);
	void SetYNJ();
	bool GetYES();
	void SetW99(bool w99);
	bool GetW99();
	void SetNODBlock();
	const wchar_t* GetTriggerType();
	void SetCheckEntity(std::weak_ptr<Entity> e);
	std::weak_ptr<Entity> GetCheckEntity();
	void SetCheckItemIndex(int itemIndex);
	int GetCheckItemIndex();
private:
	std::list<std::shared_ptr<Entity>>* globalEntity = nullptr;
	GameMap* pGameMap = nullptr;
	EntityRes* pEntityRes = nullptr;
	GameFade* pGameFade = nullptr;
	MyCamera* pMyCamera = nullptr;
	GameMsgbox* pGameMsgbox = nullptr;
	MyGame* pGame = nullptr;
	lua_State** scriptL_ptr = nullptr;
	bool cmd_PRI = false;//ϷǷס
	bool cmd_KEY = false;//μ̲
	bool cmd_WAS = false;//ͣűֱڵ
	bool cmd_NOD = false;//ȴҰz
	bool cmd_YNJ = false;//ȴѡ
	int cmd_WAI = 0;//űʱȴ
	bool cmd_W99 = false;//ȴƷ
	bool bTRA = false;
	bool bYes = false;//YNJһεѡ
	bool NOD_block = false;//ֹNOD
	bool bEachNOD = false;//1NOD2ֿ
	int targetNOD_playerIndex = 0;//NODָӦĿ
	std::weak_ptr<Entity> checkEntity;//һεʵ
	int checkItemIndex = -1;//ڵƷ±
	std::wstring mapTRA;//Ŀ괫͵ͼ
	std::wstring triggerType;//
	std::vector<char> utf8;
	std::vector<wchar_t> wbuff;
	std::vector<EventInfo> eventStack;
	void PreventJumpNOD();
	bool YesNoControl();
	bool NODStep();
};
